@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-encoding.c,v 1.69 2006/06/17 20:33:05 pkot Exp $
+  $Id: gsm-encoding.c,v 1.77 2007/08/01 20:13:24 pkot Exp $
 
   G N O K I I
 
@@ -151,19 +151,19 @@ static int char_mbtowc(wchar_t *dst, const char *src, int maxlen, MBSTATE *mbs)
 	size_t nconv;
 	char *pin;
 	char *pout;
-	int inlen;
-	int outlen;
+	size_t inlen;
+	size_t outlen;
 	iconv_t cd;
 
 	pin = (char *)src;
 	pout = (char *)dst;
 	inlen = 4;
-	outlen = 4;
+	outlen = sizeof(wchar_t);
 
 	cd = iconv_open("WCHAR_T", gn_char_get_encoding());
 	nconv = iconv(cd, &pin, &inlen, &pout, &outlen);
 	iconv_close(cd);
-	
+
 	return (char*)dst == pout ? -1 : pin-src;
 #else
 #  ifdef HAVE_WCRTOMB
@@ -180,19 +180,21 @@ static int char_wctomb(char *dst, wchar_t src, MBSTATE *mbs)
 	size_t nconv;
 	char *pin;
 	char *pout;
-	int inlen;
-	int outlen;
+	size_t inlen;
+	size_t outlen;
 	iconv_t cd;
 
 	pin = (char *)&src;
 	pout = (char *)dst;
-	inlen = 4;
+	inlen = sizeof(wchar_t);
 	outlen = 4;
-	
+
 	cd = iconv_open(gn_char_get_encoding(), "WCHAR_T");
 	nconv = iconv(cd, &pin, &inlen, &pout, &outlen);
+	if (nconv == (size_t)-1)
+		perror("iconv");
 	iconv_close(cd);
-	
+
 	return nconv == -1 ? -1 : pout-dst;
 #else
     #ifdef HAVE_WCRTOMB
@@ -397,19 +399,20 @@ void char_ascii_decode(unsigned char* dest, const unsigned char* src, int len)
 	return;
 }
 
-unsigned int char_ascii_encode(unsigned char* dest, const unsigned char* src, unsigned int len)
+size_t char_ascii_encode(char *dest, size_t dest_len, const char *src, size_t len)
 {
-	int i, j;
+	size_t i, j, extra = 0;
 
-	for (i = 0, j = 0; j < len; i++, j++) {
+	for (i = 0, j = 0; i < dest_len && j < len; i++, j++) {
 		if (char_def_alphabet_ext(src[j])) {
 			dest[i++] = GN_CHAR_ESCAPE;
 			dest[i] = char_def_alphabet_ext_encode(src[j]);
+			extra++;
 		} else {
 			dest[i] = char_def_alphabet_encode(src[j]);
 		}
 	}
-	return i;
+	return len + extra;
 }
 
 /* null terminates the string */
@@ -427,28 +430,23 @@ void char_hex_decode(unsigned char* dest, const unsigned char* src, int len)
 	return;
 }
 
-void char_hex_encode(unsigned char* dest, const unsigned char* src, int len)
+size_t char_hex_encode(char *dest, size_t dest_len, const char *src, size_t len)
 {
-	int i;
+	int i, n = dest_len / 2 >= len ? len : dest_len / 2;
 
-	for (i = 0; i < (len / 2); i++) {
+	for (i = 0; i < n; i++)
 		sprintf(dest + i * 2, "%x", char_def_alphabet_encode(src[i]));
-	}
-	return;
+	return len * 2;
 }
 
-int char_uni_alphabet_encode(unsigned char const *value, wchar_t *dest, MBSTATE *mbs)
+size_t char_uni_alphabet_encode(const char *value, size_t n, wchar_t *dest, MBSTATE *mbs)
 {
 	int length;
 
-	switch (length = char_mbtowc(dest, value, MB_CUR_MAX, mbs)) {
-	case -1:
-		dprintf("Error calling mctowb!\n");
-		*dest = '?';
-		length = 1;
-	default:
-		return length;
-	}
+	if (n > MB_CUR_MAX)
+		n = MB_CUR_MAX;
+	length = char_mbtowc(dest, value, n, mbs);
+	return length;
 }
 
 int char_uni_alphabet_decode(wchar_t value, unsigned char *dest, MBSTATE *mbs)
@@ -494,28 +492,25 @@ void char_ucs2_decode(unsigned char* dest, const unsigned char* src, int len)
 	return;
 }
 
-void char_ucs2_encode(unsigned char* dest, const unsigned char* src, int len)
+/*
+ * This function should convert "ABC" to "004100420043"
+ */
+size_t char_ucs2_encode(char *dest, size_t dest_len, const char *src, size_t len)
 {
 	wchar_t wc;
-	int i_len = 0, o_len, length;
+	int i, o_len, length;
 	MBSTATE mbs;
 
 	MBSTATE_ENC_CLEAR(mbs);
-	for (o_len = 0; i_len < len ; o_len++) {
-		switch (length = char_uni_alphabet_encode(src + i_len, &wc, &mbs)) {
-		case -1:
-			i_len++;
-			break;
-		case 0:
-			/* return at the end of the string */
-			return;
-		default:
-			i_len += length;
-			break;
-		}
-		sprintf(dest + (o_len << 2), "%04lx", wc);
+	for (i = 0, o_len = 0; i < len && o_len < dest_len / 4; o_len++) {
+		length = char_uni_alphabet_encode(src + i, len - i, &wc, &mbs);
+		if (!length)
+			return i * 4;
+		i += length;
+		/* XXX: We should probably check wchar_t size. */
+		sprintf(dest + (o_len << 2), "%04x", wc);
 	}
-	return;
+	return len * 4;
 }
 
 /* null terminates the string */
@@ -526,7 +521,8 @@ unsigned int char_unicode_decode(unsigned char* dest, const unsigned char* src,
 
 	MBSTATE_DEC_CLEAR(mbs);
 	for (i = 0; i < len / 2; i++) {
-		length = char_uni_alphabet_decode((src[i * 2] << 8) | src[(i * 2) + 1], dest, &mbs);
+		wchar_t wc = src[i * 2] << 8 | src[(i * 2) + 1];
+		length = char_uni_alphabet_decode(wc, dest, &mbs);
 		dest += length;
 		pos += length;
 	}
@@ -542,7 +538,8 @@ unsigned int char_unicode_encode(unsigned char* dest, const unsigned char* src,
 
 	MBSTATE_ENC_CLEAR(mbs);
 	while (offset < len) {
-		switch (length = char_uni_alphabet_encode(src + offset, &wc, &mbs)) {
+		length = char_uni_alphabet_encode(src + offset, len - offset, &wc, &mbs);
+		switch (length) {
 		case -1:
 			dest[pos++] =  wc >> 8 & 0xFF;
 			dest[pos++] =  wc & 0xFF;
@@ -607,7 +604,7 @@ void bin2hex(unsigned char *dest, const unsigned char *src, unsigned int len)
    destination number) for SMS sending function. */
 int char_semi_octet_pack(char *number, unsigned char *output, gn_gsm_number_type type)
 {
-	unsigned char *in_num = number;  /* Pointer to the input number */
+	char *in_num = number;  /* Pointer to the input number */
 	unsigned char *out_num = output; /* Pointer to the output */
 	int count = 0; /* This variable is used to notify us about count of already
 			  packed numbers. */
@@ -699,7 +696,7 @@ int utf8_decode(char *outstring, size_t outlen, const char *instring, size_t inl
 
 	pin = (char *)instring;
 	pout = outstring;
-	
+
 	cd = iconv_open(gn_char_get_encoding(), "UTF-8");
 	nconv = iconv(cd, &pin, &inlen, &pout, &outlen);
 	iconv_close(cd);
@@ -795,43 +792,40 @@ int string_base64(const char *instring)
 }
 
 /*
-   encodes a null-terminated input string with base64 encoding.
-   the buffer outstring needs to be at least 1.333 times bigger than the input string length
+   Encodes a null-terminated input string with base64 encoding.
+   The buffer outstring needs to be at least 1.333 times bigger than the input string length.
+   outlen is the size of the oustring buffer excluding null termination.
 */
 int base64_encode(char *outstring, int outlen, const char *instring, int inlen)
 {
-	char *in1, *pin, *pout;
+	char *pin, *pout;
 	char *outtemp = NULL;
-	int inleft, outleft, inprocessed;
-	unsigned int i1, i2, i3, i4;
-
-
-	/* copy the input string, need multiple of 3 chars */
-	in1 = malloc(inlen + 3);
-	memset(in1, 0, inlen + 3);
-	memcpy(in1, instring, inlen);
+	int inleft, outleft;
 
 	pout = outstring;
 	inleft = inlen;
 	outleft = outlen;
-	inprocessed = 0;
-	pin = in1;
+	pin = instring;
 
-	for (; (outleft > 3) && (inprocessed < inlen); ) {
-		if (!(*pin))
-			break;
+	/* This is in case someone have us not appropriate buffer for outstring */
+	while (outleft > 3 && inleft > 0) {
+		int a, b, c;
+		unsigned int i1, i2, i3, i4;
+
+		a = *pin++;
+		b = (*pin) ? *(pin++) : 0;
+		c = (*pin) ? *(pin++) : 0;
 
 		/* calculate the indexes */
-		i1 = (pin[0] & 0xFC) >> 2;
-		i2 = ((pin[0] & 0x03) << 4) | ((pin[1] & 0xF0) >> 4);
-		i3 = ((pin[1] & 0x0F) << 2) | ((pin[2] & 0xC0) >> 6);
-		i4 = pin[2] & 0x3F;
-		pin += 3;
-
-		/* assign the characters or the padding char, if necessary */
+		i1 = (a & 0xfc) >> 2;
 		*(pout++) = base64_alphabet[i1];
+
+		i2 = ((a & 0x03) << 4) | ((b & 0xf0) >> 4);
 		*(pout++) = base64_alphabet[i2];
+
 		inleft--;
+
+		i3 = ((b & 0x0f) << 2) | ((c & 0xc0) >> 6);
 		if (!inleft) {
 			*(pout++) = '=';
 		} else {
@@ -839,6 +833,7 @@ int base64_encode(char *outstring, int outlen, const char *instring, int inlen)
 			inleft--;
 		}
 
+		i4 = c & 0x3f;
 		if (!inleft)
 			*(pout++) = '=';
 		else {
@@ -846,17 +841,14 @@ int base64_encode(char *outstring, int outlen, const char *instring, int inlen)
 			inleft--;
 		}
 
-		/* update the counters */
-		inprocessed += 3;
 		outleft -= 4;
 	}
 
-	if (outleft > 0) *pout = 0;
+	*pout = 0;
+
 	if (outtemp)
 		free(outtemp);
 
-	free(in1);
-
 	return pout - outstring;
 }
 
