@@ -1,6 +1,6 @@
 /*
 
-  $Id: ldif.c,v 1.16 2006/08/06 20:34:44 pkot Exp $
+  $Id: ldif.c,v 1.20 2007/08/08 15:07:56 dforsi Exp $
   
   G N O K I I
 
@@ -45,28 +45,27 @@
 */
 static int ldif_entry_write(FILE *f, const char *parameter, const char *value, int convertToUTF8)
 {
-	char *buf;
+	char *buf = NULL;
 	int n, inlen, buflen;
 
 	if (string_base64(value)) {
 		inlen = strlen(value);
-		buf = NULL;
-		n = 3 * inlen;
+		n = 2 * inlen * 4 / 3; /* * 2   -> UTF8
+					* * 4/3 -> base 64
+					*/
+		if (n % 4)
+			n += (4 - (n % 4)); /* base 64 padds with '=' to length dividable by 4 */
 
-		do {
-			buflen = n;
-			if (buf) free(buf);
-			buf = malloc(buflen + 1);
-			if (convertToUTF8)
-				n = utf8_base64_encode(buf, buflen, value, inlen);
-			else
-				n = base64_encode(buf, buflen, value, inlen);
-		} while (n >= buflen);
+		buflen = n;
+		buf = malloc(buflen + 1);
+		if (convertToUTF8)
+			n = utf8_base64_encode(buf, buflen, value, inlen);
+		else
+			n = base64_encode(buf, buflen, value, inlen);
 
 		fprintf(f, "%s:: %s\n", parameter, buf);
 
 		free(buf);
-
 	} else {
 		fprintf(f, "%s: %s\n", parameter, value);
 	}
@@ -102,6 +101,14 @@ GNOKII_API int gn_phonebook2ldif(FILE *f, gn_phonebook_entry *entry)
 		ldif_entry_write(f, "businessGroup", aux2, 1);
 	}
 
+	if (entry->subentries_count == 0) {
+		ldif_entry_write(f, "telephoneNumber", entry->number, 1);
+	}
+
+	if (entry->address.has_address) {
+		ldif_entry_write(f, "homePostalAddress", entry->address.post_office_box, 1);
+	}
+
 	/* Add ext. pbk info if required */
 	for (i = 0; i < entry->subentries_count; i++) {
 		switch (entry->subentries[i].entry_type) {
@@ -128,6 +135,8 @@ GNOKII_API int gn_phonebook2ldif(FILE *f, gn_phonebook_entry *entry)
 			case GN_PHONEBOOK_NUMBER_Work:
 				ldif_entry_write(f, "workPhone", entry->subentries[i].data.number, 1);
 				break;
+			case GN_PHONEBOOK_NUMBER_None:
+			case GN_PHONEBOOK_NUMBER_Common:
 			case GN_PHONEBOOK_NUMBER_General:
 				ldif_entry_write(f, "telephoneNumber", entry->subentries[i].data.number, 1);
 				break;
@@ -221,6 +230,8 @@ GNOKII_API int gn_ldif2phonebook(FILE *f, gn_phonebook_entry *entry)
 	for (i = 0; i < entry->subentries_count && entry->number[0] == 0; i++) {
 		if (entry->subentries[i].entry_type == GN_PHONEBOOK_ENTRY_Number) {
 			switch (entry->subentries[i].number_type) {
+			case GN_PHONEBOOK_NUMBER_None:
+			case GN_PHONEBOOK_NUMBER_Common:
 			case GN_PHONEBOOK_NUMBER_General:
 			case GN_PHONEBOOK_NUMBER_Work: 
 			case GN_PHONEBOOK_NUMBER_Home:
