@@ -1,6 +1,6 @@
 /*
 
-  $Id: compat.h,v 1.46 2006/08/10 22:17:40 pkot Exp $
+  $Id: compat.h,v 1.57 2007/07/29 17:44:11 pkot Exp $
 
   G N O K I I
 
@@ -37,6 +37,7 @@
 #include "config.h"
 
 #include <stdlib.h>
+#include <stdio.h>
 
 #ifdef WIN32
 #  include <windows.h>
@@ -60,6 +61,9 @@
 #endif
 
 #ifdef HAVE_STRING_H
+#  ifndef _GNU_SOURCE
+#    define _GNU_SOURCE 1
+#  endif
 #  include <string.h>
 #endif
 
@@ -95,6 +99,22 @@
 #  include <wchar.h>
 #endif
 
+#ifdef HAVE_LIMITS_H
+#  include <limits.h>
+#endif
+
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+
+#ifdef HAVE_TERMIOS_H
+#  include <termios.h>
+#endif
+
+#if !defined(INT_MAX)
+#  define INT_MAX 2147483647
+#endif
+
 /*
  * The following ifdef block is the standard way of creating macros which make
  * exporting from a DLL simpler. All files within this DLL are compiled with 
@@ -118,6 +138,11 @@
 #    define GNOKII_API
 #endif /* WIN32 */
 
+/* I assume that HAVE_STRNDUP always implies HAVE_STRING_H */
+#ifndef HAVE_STRNDUP
+extern char *strndup(const char *src, size_t n);
+#endif
+
 #ifndef	HAVE_TIMEOPS
 
 #undef timerisset
@@ -186,6 +211,13 @@ int vasprintf(char **ptr, const char *format, va_list ap);
 time_t timegm(struct tm *tm);
 #endif
 
+#ifndef HAVE_GETLINE
+#  ifdef HAVE_SYS_PARAM_H
+#    include <sys/param.h>
+#  endif
+int getline(char **line, size_t *len, FILE *stream);
+#endif
+
 /*
  * The following code was taken from W. Richard Stevens'
  * "UNIX Network Programming", Volume 1, Second Edition.
@@ -259,6 +291,10 @@ time_t timegm(struct tm *tm);
 	typedef int int32_t;
 #endif
 
+#ifndef HAVE_U_INT8_T
+	typedef u_int_8_t;
+#endif
+
 #ifdef HAVE_WCRTOMB
 #  define MBSTATE mbstate_t
 #  define MBSTATE_ENC_CLEAR(x) memset(&(x), 0, sizeof(mbstate_t))
@@ -269,4 +305,14 @@ time_t timegm(struct tm *tm);
 #  define MBSTATE_DEC_CLEAR(x) wctomb(NULL, 0)
 #endif
 
+/* MS Visual C does not have va_copy */
+#ifndef va_copy
+#  ifdef __va_copy
+#    define va_copy(dest, src)    __va_copy((dest), (src))
+#  else
+#    define va_copy(dest, src)    memcpy(&(dest), &(src), sizeof(va_list))
+#  endif
+#endif
+
+
 #endif
