@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii.h,v 1.112 2007/07/10 15:37:02 pkot Exp $
+  $Id: gnokii.h,v 1.114 2007/10/05 21:01:20 pkot Exp $
 
   G N O K I I
 
@@ -41,7 +41,7 @@ extern "C" {
 #endif
 
 /* Some portability definitions first */
-#if defined(__linux__) || defined(__GLIBC__)
+#if defined(__linux__) || defined(__GLIBC__) || defined(__CYGWIN__)
 #  include <stdint.h>
 #  include <sys/time.h>
 #elif defined(__svr4__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(__MACH__)
@@ -69,10 +69,10 @@ typedef unsigned char uint8_t;
  * LIBGNOKII_VERSION_MINOR = GNOKII_MINOR
  * LIBGNOKII_VERSION_RELEASE = GNOKII_RELEASE
  */
-#define LIBGNOKII_VERSION_STRING "3.2.0"
+#define LIBGNOKII_VERSION_STRING "3.2.1"
 #define LIBGNOKII_VERSION_MAJOR 3
 #define LIBGNOKII_VERSION_MINOR 2
-#define LIBGNOKII_VERSION_RELEASE 0
+#define LIBGNOKII_VERSION_RELEASE 1
 #define LIBGNOKII_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
 
 #define LIBGNOKII_VERSION \
