@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_lowlevel.c,v 1.95 2006/04/25 21:52:49 deller Exp $
+  $Id: xgnokii_lowlevel.c,v 1.99 2007/08/23 14:12:47 pkot Exp $
   
   X G N O K I I
 
@@ -30,7 +30,9 @@
 
 */
 
-#include <unistd.h>
+#ifndef WIN32
+#  include <unistd.h>
+#endif
 #include <pthread.h>
 #include <string.h>
 #include <glib.h>
@@ -1214,7 +1216,21 @@ void *GUI_Connect(void *a)
 	phoneMonitor.working = _("Connecting...");
 	if (fbusinit() != GN_ERR_NONE) {
 		gn_log_xdebug("Initialization failed...\n");
-		MainExit();
+		MainExit(NULL);
+		return NULL;
+	}
+
+	if (!xgnokiiConfig.allowBreakage &&				/* User did not allow to break the phone */
+		(phoneMonitor.supported & PM_XGNOKIIBREAKAGE) &&	/* Phone is known to be on the black list */
+		strncmp(xgnokiiConfig.model, "AT", 2)) {		/* We're not using it in AT mode */
+		gn_log_xdebug("Detected phone known to be broken using xgnokii\n");
+		MainExit(_("It has been reported that your phone is known to be broken by xgnokii.\n"
+			   "Exiting application to avoid breakage. If you want to take a risk and\n"
+			   "run xgnokii anyway, set:\n\n"
+			   "\tallow_breakage = 1\n\n"
+			   "in xgnokii section in your config file.\n"
+			   "See http://thread.gmane.org/gmane.linux.drivers.gnokii/3195 for details.\n"));
+		return NULL;
 	}
 
 	gn_log_xdebug("Phone connected. Starting monitoring...\n");
